
# Type: sequence variant qualifier


a qualifier used in an association where the variant

URI: [biolink:sequence_variant_qualifier](https://w3id.org/biolink/vocab/sequence_variant_qualifier)


## Domain and Range

[Association](Association.md) ->  <sub>OPT</sub> [SequenceVariant](SequenceVariant.md)

## Parents

 *  is_a: [association slot](association_slot.md)

## Children


## Used by

 * [GeneHasVariantThatContributesToDiseaseAssociation](GeneHasVariantThatContributesToDiseaseAssociation.md)
